@@ -9,17 +9,20 @@ def get_connect(uri,user,pwd):
     except Exception as error:
         print(error)
     if(connect==1):
-        return driver
+        return (True,driver)
     else:
         print("please check your hostname , userid and password")
+        return (False,driver)
 ##get the count
 def count_node(uri,user,pwd):
-        driver=get_connect(uri,user,pwd)
-        session=driver.session()
-        count_query="""match (n) return count(n) as count"""
-        count_result=session.run(count_query)
-        for count in count_result:
-            nodecount=count["count"]
-        return nodecount
+       
+        con,driver=get_connect(uri,user,pwd)
+        if(con):
+            session=driver.session()
+            count_query="""match (n) return count(n) as count"""
+            count_result=session.run(count_query)
+            for count in count_result:
+                nodecount=count["count"]
+            return nodecount
 
     
\ No newline at end of file
